@@ -731,7 +731,7 @@ class TestPlanCli:
         assert "usage:" in output
         assert "submit" in output
 
-    def test_plan_cli(self, mocker, monkeypatch, plan_config):
+    def test_plan_cli(self, mocker, monkeypatch, plan_config, tuxsuite_config):
         plan = mocker.patch("tuxsuite.Plan")
         monkeypatch.setattr(
             sys,
@@ -748,7 +748,13 @@ class TestPlanCli:
         plan.assert_called_once()
 
     def test_plan_cli_options(
-        self, mocker, monkeypatch, plan_config, tuxsuite_config, capsys
+        self,
+        mocker,
+        monkeypatch,
+        sample_patch_tgz,
+        plan_config,
+        tuxsuite_config,
+        capsys,
     ):
         plan = mocker.patch("tuxsuite.Plan")
         monkeypatch.setattr(
@@ -762,10 +768,17 @@ class TestPlanCli:
                 "--download",
                 "--show-logs",
                 str(plan_config),
+                f"--patch-series={sample_patch_tgz}",
             ],
         )
         tuxsuite.cli.main()
-        plan.assert_called_once()
+        plan.assert_called_with(
+            mocker.ANY,
+            git_repo="https://git.example.com/linux.git",
+            git_ref="master",
+            git_sha=None,
+            patch_series=sample_patch_tgz,
+        )
 
     def test_plan_empty_config(
         self, mocker, monkeypatch, plan_config, tuxsuite_config, capsys
