@@ -3,14 +3,7 @@
 import sys
 import json
 import pytest
-from tuxsuite.cli.argparse import setup_parser
-from tuxsuite.cli.build import (
-    handle_config,
-    handle_get,
-    handle_list,
-    handle_logs,
-    handle_wait,
-)
+import tuxsuite
 
 
 @pytest.fixture
@@ -98,19 +91,17 @@ def test_build_handle_config(mocker, config, response, monkeypatch):
     monkeypatch.setattr(
         sys, "argv", ["tuxsuite", "build", "config", "205Yag6znViIi4oLWFVDxJC4avb"]
     )
-    options = setup_parser(config.group, config.project).parse_args()
     response.status_code = 200
     response._content = b'{"download_url": "b"}'
     config_req = mocker.patch("requests.get", return_value=response)
-    result = handle_config(options, config)
-    assert result == 0
+    tuxsuite.cli.main()
     assert config_req.call_count == 2
 
     # Test failure case when the response is not 200
     response.status_code = 500
     config_req = mocker.patch("requests.get", return_value=response)
     with pytest.raises(NotImplementedError):
-        result = handle_config(options, config)
+        tuxsuite.cli.main()
     assert config_req.call_count == 1
 
 
@@ -118,12 +109,10 @@ def test_build_handle_get(mocker, build_json, config, response, monkeypatch):
     monkeypatch.setattr(
         sys, "argv", ["tuxsuite", "build", "get", "205Yag6znViIi4oLWFVDxJC4avb"]
     )
-    options = setup_parser(config.group, config.project).parse_args()
     response.status_code = 200
     response._content = build_json
     get_req = mocker.patch("requests.get", return_value=response)
-    result = handle_get(options, config)
-    assert result == 0
+    tuxsuite.cli.main()
     assert get_req.call_count == 1
 
     # Test json out
@@ -132,41 +121,37 @@ def test_build_handle_get(mocker, build_json, config, response, monkeypatch):
         "argv",
         ["tuxsuite", "build", "get", "205Yag6znViIi4oLWFVDxJC4avb", "--json"],
     )
-    options = setup_parser(config.group, config.project).parse_args()
     response.status_code = 200
     response._content = build_json
     get_req = mocker.patch("requests.get", return_value=response)
-    result = handle_get(options, config)
-    assert result == 0
+    tuxsuite.cli.main()
     assert get_req.call_count == 1
 
     # Test failure case when the response is not 200
     response.status_code = 500
     get_req = mocker.patch("requests.get", return_value=response)
     with pytest.raises(NotImplementedError):
-        result = handle_get(options, config)
+        tuxsuite.cli.main()
     assert get_req.call_count == 1
 
 
 def test_build_handle_list(mocker, build_list_json, config, response, monkeypatch):
     monkeypatch.setattr(sys, "argv", ["tuxsuite", "build", "list"])
     monkeypatch.setattr("sys.stdout.isatty", lambda: True)
-    options = setup_parser(config.group, config.project).parse_args()
     response.status_code = 200
     response._content = build_list_json
     list_req = mocker.patch("requests.get", return_value=response)
     with pytest.raises(SystemExit) as exit:
-        handle_list(options, config)
+        tuxsuite.cli.main()
     assert exit.value.code == 0
     assert list_req.call_count == 2
 
     # Test json out
     monkeypatch.setattr(sys, "argv", ["tuxsuite", "build", "list", "--json"])
-    options = setup_parser(config.group, config.project).parse_args()
     response.status_code = 200
     response._content = build_list_json
     list_req = mocker.patch("requests.get", return_value=response)
-    handle_list(options, config)
+    tuxsuite.cli.main()
     assert exit.value.code == 0
     assert list_req.call_count == 1
 
@@ -174,7 +159,7 @@ def test_build_handle_list(mocker, build_list_json, config, response, monkeypatc
     response.status_code = 500
     list_req = mocker.patch("requests.get", return_value=response)
     with pytest.raises(NotImplementedError):
-        handle_list(options, config)
+        tuxsuite.cli.main()
     assert list_req.call_count == 1
 
 
@@ -182,26 +167,23 @@ def test_build_handle_logs(mocker, config, response, monkeypatch):
     monkeypatch.setattr(
         sys, "argv", ["tuxsuite", "build", "logs", "205Yag6znViIi4oLWFVDxJC4avb"]
     )
-    options = setup_parser(config.group, config.project).parse_args()
     response.status_code = 200
     response._content = b'{"download_url": "b"}'
     logs_req = mocker.patch("requests.get", return_value=response)
-    result = handle_logs(options, config)
-    assert result == 0
+    tuxsuite.cli.main()
     assert logs_req.call_count == 2
 
     # Test failure case when the response is not 200
     response.status_code = 500
     logs_req = mocker.patch("requests.get", return_value=response)
     with pytest.raises(NotImplementedError):
-        result = handle_logs(options, config)
+        tuxsuite.cli.main()
     assert logs_req.call_count == 1
 
     # Test when log is unavailable - due to infra error
     response.status_code = 404
     logs_req = mocker.patch("requests.get", return_value=response)
-    result = handle_logs(options, config)
-    assert result == 0
+    tuxsuite.cli.main()
     assert logs_req.call_count == 1
 
 
@@ -211,17 +193,15 @@ def test_build_handle_wait(mocker, build_json, config, response, monkeypatch):
         "argv",
         ["tuxsuite", "build", "wait", "205Yag6znViIi4oLWFVDxJC4avb"],
     )
-    options = setup_parser(config.group, config.project).parse_args()
     response.status_code = 200
     response._content = build_json
     wait_req = mocker.patch("requests.get", return_value=response)
-    result = handle_wait(options, config)
-    assert result == 0
+    tuxsuite.cli.main()
     assert wait_req.call_count == 1
 
     # Test failure case when the response is not 200
     response.status_code = 500
     wait_req = mocker.patch("requests.get", return_value=response)
     with pytest.raises(NotImplementedError):
-        result = handle_wait(options, config)
+        tuxsuite.cli.main()
     assert wait_req.call_count == 1
