@@ -5,14 +5,16 @@
 This is the tuxsuite module.
 """
 
-__version__ = "1.3.0"
+__version__ = "1.4.0"
 
 
 from . import build
 from . import config
 from . import schema, exceptions
-import logging
+
 from abc import ABC, abstractmethod
+from copy import deepcopy
+import logging
 
 
 logging.basicConfig(format="%(levelname)s: %(message)s")
@@ -149,6 +151,19 @@ class BuildPlan(PlanType):
                 tests = [cfg["test"]]
             elif "tests" in cfg:
                 tests = cfg["tests"]
+            new_tests = []
+            for test in tests:
+                if "sharding" in test:
+                    sharding = test.pop("sharding")
+                    for i in range(1, sharding + 1):
+                        t = deepcopy(test)
+                        t.setdefault("parameters", {})
+                        t["parameters"]["SHARD_NUMBER"] = sharding
+                        t["parameters"]["SHARD_INDEX"] = i
+                        new_tests.append(t)
+                else:
+                    new_tests.append(test)
+            tests = new_tests
 
             if builds:
                 for build_item in builds:
