@@ -191,9 +191,13 @@ def show_log(build, download, output_dir):
         for line in open(os.path.join(output_dir, build.uid, "build.log")):
             print(line.strip(), file=sys.stderr)
     else:
-        tuxsuite.download.download_file(
-            os.path.join(build.status["download_url"], "build.log"), sys.stderr.buffer
-        )
+        if build.status.get("download_url"):
+            tuxsuite.download.download_file(
+                os.path.join(build.status["download_url"], "build.log"),
+                sys.stderr.buffer,
+            )
+        else:
+            error("download_url empty")
 
 
 def format_build(build, icon, color, msg):
